%P
N = 20.87e6;
% Taxa de reproduo
R0 = 2.7;
% Tempo de infeco
t_infective = 3.48;
%Tempo de incubao
t_incubation = 3.69;

% Parmetros da Equao de diferena
alpha = 1/t_incubation;
gamma = 1/t_infective;
beta = R0*gamma;
% Subnotificao
subnot = 0.049;

%tempo de simulao dias
T = 365;
isoat=54;
isoloc=80;

xinit=[N-(1+80)/subnot,80/subnot,3/subnot,0,0]';

% #1 - Sem isolamento atual
isol1 = [0 0;
         365 0];
out1=seir(alpha,beta,gamma,N,T,isol2,xinit,subnot);
% #2 - Isolamento atual
isol2=[0 0;
       10  isoat;
       365 isoat];
out2=seir(alpha,beta,gamma,N,T,isol2,xinit,subnot);

% #3 - Lockdown duas semanas em junho
isol3=[0 0;
       10 isoat;
       100 isoloc;
       114 isoat;
       T isoat];
out3=seir(alpha,beta,gamma,N,T,isol3,xinit,subnot);

% # 4 - Lockdown 7 finais de semana em junho
isol4= [0 0; 10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 123 isoat; 
        128 isoloc; 130 isoat; 135 isoloc; 137 isoat; 142 isoloc; 
        144 isoat; T,  isoat];
out4=seir(alpha,beta,gamma,N,T,isol4,xinit,subnot);

% # 5 - Lockdown 5 finais de semana (incluindo sexta-feira)

isol5 = [0   0; 10 isoat; 100 isoloc; 103 isoat; 
         107 isoloc; 110 isoat; 114 isoloc;
         117 isoat; 121 isoloc; 124 isoat; 
         128 isoloc; 131 isoat; T  isoat];
out5=seir(alpha,beta,gamma,N,T,isol5,xinit,subnot);

% # 6 - Lockdown 5 finais de semana (incluindo sexta-feira) quinzenal
isol6= [0   0; 10 isoat; 100 isoloc; 103 isoat; 114, isoloc;
        117 isoat; 128 isoloc; 131 isoat; 142 isoloc; 
        145 isoat; 156 isoloc; 159 isoat; T  isoat];
out6=seir(alpha,beta,gamma,N,T,isol6,xinit,subnot);

% #7 - Lockdown duas semanas em junho - comeando 1 ms depois
isol7=[0 0;
    10 isoat;
    130 isoloc;
    144 isoat;
    T isoat];
out7=seir(alpha,beta,gamma,N,T,isol7,xinit,subnot);

% #8 - Lockdown 7 finais de semana em junho (+30 dias)
isol8= [0 0; 
        10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 123 isoat; 
        128 isoloc; 130 isoat; 135 isoloc; 137 isoat; 142 isoloc; 
        144 isoat; 
        T,  isoat];
isol8(3:end-1,1)=isol8(3:end-1,1)+30
out8=seir(alpha,beta,gamma,N,T,isol8,xinit,subnot);

% #9 - Lockdown 8 finais de semana em junho
isol9= [0 0; 10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 
        123 isoat; 128 isoloc; 130 isoat; 135 isoloc; 
        137 isoat; 142 isoloc; 144 isoat; 149 isoloc; 
        151 isoat; 153 isoloc; 155 isoat;
        T,  isoat];
out9=seir(alpha,beta,gamma,N,T,isol9,xinit,subnot);

% #10 - Lockdown 7 finais de semana comeando k dias antes
isol10= [0 0; 10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 123 isoat; 
        128 isoloc; 130 isoat; 135 isoloc; 137 isoat; 142 isoloc; 
        144 isoat; T,  isoat];
isol10(3:end-1,1)=isol10(3:end-1,1)-20;    
out10=seir(alpha,beta,gamma,N,T,isol10,xinit,subnot);

% #11 - Lockdown duas semanas em maio
isol11=[0 0;
       10 isoat;
       70 isoloc;
       84 isoat;
       T isoat];
out11=seir(alpha,beta,gamma,N,T,isol11,xinit,subnot);

% #12 - Lockdown 7 finais de semana comeando 50 dias antes
isol12= [0 0; 10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 123 isoat; 
        128 isoloc; 130 isoat; 135 isoloc; 137 isoat; 142 isoloc; 
        144 isoat; T,  isoat];
isol12(3:end-1,1)=isol12(3:end-1,1)-50;    
out12=seir(alpha,beta,gamma,N,T,isol12,xinit,subnot);


%Tempo em data
t=[1:365]+datenum('10-Mar-2020');

figure(1)
plot(t,out2.ni,t,out3.ni,'r');
datetick('x','dd/mm/yy','keeplimits')
datetick('x','dd/mm/yy','keeplimits')
grid
title('(a) - Sem isolamento X Lockdown 14 dias')

figure(2)
plot(t,out2.ni,t,out4.ni,'r');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(b) - Sem isolamento X 7 fins de semana')

figure(3)
plot(t,out2.ni,t,out5.ni,'r');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(c) - Sem isolamento X 3 fins de semana (com sexta)')
xlabel('Dias')

figure(4)
plot(t,out2.ni,t,out6.ni,'r');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(d) - Sem isolamento X 5 fins de semana (com sexta) - Quinzenal')
xlabel('Dias')

figure(5)
plot(t,out2.ni,t,out7.ni,'r',t,out8.ni,'b');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(e) - Sem isolamento X 14 dias X 7 fins de semana')
xlabel('Dias')

figure(6)
plot(t,out2.ni,t,out9.ni,'r');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(f) - Sem isolamento X 8 fins de semana')
xlabel('Dias')

figure(7)
plot(t,out2.ni,t,out3.ni,'r',t,out10.ni,'b');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(g) - Sem isolamento X dias antes do isolamento de 14')
xlabel('Dias')

figure(8)
plot(t,out2.ni,t,out11.ni,'r',t,out12.ni,'b');
datetick('x','dd/mm/yy','keeplimits')
grid
title('(h) - Sem isolamento X 14 dias X 7 fins de semana - Mais cedo')
xlabel('Dias')


A=[out2.ni; out3.ni; out4.ni; out5.ni; out6.ni;
   out7.ni; out8.ni; out9.ni; out10.ni;
   out11.ni; out12.ni];
perc=max(A')/max(max(A'))*100;
disp(perc)
