%Erivelton G. Nepomuceno
%Mrcio J. Lacerda
%15/05/2020
%Efeito do Lockdown no espalhamento da pandemia
%Comparao de diferentes cenrios para o estado de MG

clear all

%Populao
N = 20.87e6;
% Taxa de reproduo
R0 = 2.7;
% Tempo de infeco
t_infective = 3.48;
%Tempo de incubao
t_incubation = 3.69;

% Parmetros da Equao de diferena
alpha = 1/t_incubation;
gamma = 1/t_infective;
beta = R0*gamma;
% Subnotificao
subnot = 0.049;

%tempo de simulao dias
T = 365;
isoat=54;
isoloc=80;

xinit=[N-(1+80)/subnot,80/subnot,1/subnot,0,0]';

% #1 - Sem isolamento atual
isol1 = [0 0;
         365 0];
out1=seir(alpha,beta,gamma,N,T,isol1,xinit,subnot);
% #2 - Isolamento atual
isol2=[0 0;
       10  isoat;
       365 isoat];
out2=seir(alpha,beta,gamma,N,T,isol2,xinit,subnot);

%Inicio
delay=[-10 0 10 20];
for k=1:length(delay)
    % #7 - Lockdown duas semanas em junho - comeando 1 ms depois
    isol3=[0 0;
        10 isoat;
        100 isoloc;
        114 isoat;
        T isoat];
    isol3(3:end-1,1)=isol3(3:end-1,1)+delay(k);
    out3(k)=seir(alpha,beta,gamma,N,T,isol3,xinit,subnot);
    
    % #4 - Lockdown 7 finais de semana em junho (+30 dias)
    isol4= [0 0;
        10 isoat; 100 isoloc; 102 isoat; 107 isoloc;
        109 isoat; 114 isoloc; 116 isoat; 121 isoloc; 123 isoat;
        128 isoloc; 130 isoat; 135 isoloc; 137 isoat; 142 isoloc;
        144 isoat;
        T,  isoat];
    isol4(3:end-1,1)=isol4(3:end-1,1)+delay(k);
    out4(k)=seir(alpha,beta,gamma,N,T,isol4,xinit,subnot);
    
    %Tempo em data
    t=[1:365]+datenum('10-Mar-2020');
    
    figure(k)
    set(0,'DefaultAxesFontSize',16,'DefaultAxesFontName', 'Times New Roman')
    plot(t,out2.c,'k',t,out3(k).c,'r',t,out4(k).c,'b');
    box off
    datetick('x','mmm/yy','keeplimits')
    grid    
    ylabel('C_k')
    print(sprintf('fig%d',k),'-depsc')
    
    %Relatrio
    B=[out2.c; out3(k).c; out4(k).c];
    maxB(k,:)=max(B');
    pB(:,k)=(1-max(B')/max(max(B')))*100;        
    ind(k)=100*(pB(3,k)/pB(2,k)-1);    
end
%Incio do Lockdown
disp('Incio do Lockdown')
[(delay+100)' int64(round(maxB)) ind']





